@@ -16,10 +16,12 @@ from yellowdog_client.model import (
     Instance,
     KeyringSummary,
     MachineImageFamilySummary,
+    Namespace,
     NamespacePolicy,
     NamespaceStorageConfiguration,
     Node,
     ObjectPath,
+    PermissionDetail,
     ProvisionedWorkerPool,
     Role,
     Task,
@@ -46,10 +48,12 @@ Item = TypeVar(
     Instance,
     KeyringSummary,
     MachineImageFamilySummary,
+    Namespace,
     NamespacePolicy,
     NamespaceStorageConfiguration,
     Node,
     ObjectPath,
+    PermissionDetail,
     ProvisionedWorkerPool,
     Role,
     Task,
