@@ -37,6 +37,7 @@ from yellowdog_client.model import (
     InternalUser,
     KeyringSummary,
     MachineImageFamilySummary,
+    Namespace,
     NamespacePolicy,
     Node,
     ObjectDetail,
@@ -71,10 +72,12 @@ from yellowdog_cli.utils.settings import (
     MAX_LINES_COLOURED_FORMATTING,
     MAX_TABLE_DESCRIPTION,
     NAMESPACE_OBJECT_STORE_PREFIX_SEPARATOR,
+    PROP_ACCESS_DELEGATES,
+    PROP_ADMIN_GROUP,
+    PROP_CREATED_BY_USER_ID,
     PROP_CREATED_TIME,
     PROP_ID,
     PROP_INSTANCE_PRICING,
-    PROP_RESOURCE,
     PROP_SUPPORTING_RESOURCE_CREATED,
     PROP_TRAITS,
     WARNING_STYLE,
@@ -98,10 +101,13 @@ class PrintLogHighlighter(RegexHighlighter):
         r"(?P<date_time>[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]"
         r" [0-9][0-9]:[0-9][0-9]:[0-9][0-9])",
         r"(?P<quoted>'[a-zA-Z0-9-._=;:\/\\\[\]{}+#@$£%\^&\*\(\)~`<>?]*')",
-        r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9abcdef-]*)",
         r"(?P<ydid>ydid:[a-z]*:[0-9abcdef-]*)",
+        r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9abcdef-]*)",
         r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9abcdef-]*:[0-9]*)",
         r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9abcdef-]*:[0-9]*:[0-9]*)",
+        r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9ABCDEF]*:[0-9abcdef-]*)",
+        r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9ABCDEF]*:[0-9abcdef-]*:[0-9]*)",
+        r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9ABCDEF]*:[0-9abcdef-]*:[0-9]*:[0-9]*)",
         r"(?P<url>(https?):((//)|(\\\\))+[\w\d:#@%/;$~_?\+-=\\\.&]*)",
     ] + HIGHLIGHTED_STATES
 
@@ -120,6 +126,9 @@ class PrintTableHighlighter(RegexHighlighter):
         r"(?P<ydid>ydid:[a-z]*:[0-9abcdef-]*)",
         r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9abcdef-]*:[0-9]*)",
         r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9abcdef-]*:[0-9]*:[0-9]*)",
+        r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9ABCDEF]*:[0-9abcdef-]*)",
+        r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9ABCDEF]*:[0-9abcdef-]*:[0-9]*)",
+        r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9ABCDEF]*:[0-9abcdef-]*:[0-9]*:[0-9]*)",
     ] + HIGHLIGHTED_STATES
 
 
@@ -227,19 +236,24 @@ def print_warning(
 TYPE_MAP = {
     AWSAvailabilityZone: "AWS Availability Zones",
     Allowance: "Allowance",
+    Application: "Application",
     ComputeRequirement: "Compute Requirement",
     ComputeRequirementTemplateSummary: "Compute Requirement Template",
     ComputeSourceTemplateSummary: "Compute Source Template",
     ConfiguredWorkerPool: "Configured Worker Pool",
+    Group: "Group",
     KeyringSummary: "Keyring",
     MachineImageFamilySummary: "Machine Image Family",
+    Namespace: "Namespace",
     NamespacePolicy: "Namespace Policy",
     Node: "Node",
     ObjectPath: "Object Path",
     PermissionDetail: "Permission",
     ProvisionedWorkerPool: "Provisioned Worker Pool",
+    Role: "Role",
     Task: "Task",
     TaskGroup: "Task Group",
+    User: "User",
     WorkRequirementSummary: "Work Requirement",
     Worker: "Worker",
     WorkerPoolSummary: "Worker Pool",
@@ -277,7 +291,7 @@ def get_type_name(obj: Item) -> str:
 
 def compute_requirement_table(
     cr_list: List[ComputeRequirement],
-) -> (List[str], List[List]):
+) -> Tuple[List[str], List[List]]:
     headers = [
         "#",
         "Compute Requirement Name",
@@ -314,7 +328,7 @@ def compute_requirement_table(
 
 def work_requirement_table(
     wr_summary_list: List[WorkRequirementSummary],
-) -> (List[str], List[List]):
+) -> Tuple[List[str], List[List]]:
     headers = [
         "#",
         "Work Requirement Name",
@@ -342,7 +356,7 @@ def work_requirement_table(
 
 def task_group_table(
     task_group_list: List[TaskGroup],
-) -> (List[str], List[List]):
+) -> Tuple[List[str], List[List]]:
     headers = ["#", "Task Group Name", "Status", "Task Group ID"]
     table = []
     for index, task_group in enumerate(task_group_list):
@@ -362,7 +376,7 @@ def task_group_table(
     return headers, table
 
 
-def task_table(task_list: List[Task]) -> (List[str], List[List]):
+def task_table(task_list: List[Task]) -> Tuple[List[str], List[List]]:
     headers = ["#", "Task Name", "Status", "Task ID"]
     table = []
     for index, task in enumerate(task_list):
@@ -379,7 +393,7 @@ def task_table(task_list: List[Task]) -> (List[str], List[List]):
 
 def worker_pool_table(
     client: PlatformClient, worker_pool_summaries: List[WorkerPoolSummary]
-) -> (List[str], List[List]):
+) -> Tuple[List[str], List[List]]:
     headers = [
         "#",
         "Worker Pool Name",
@@ -405,7 +419,7 @@ def worker_pool_table(
 
 def compute_requirement_template_table(
     crt_summaries: List[ComputeRequirementTemplateSummary],
-) -> (List[str], List[List]):
+) -> Tuple[List[str], List[List]]:
     headers = [
         "#",
         "Name",
@@ -443,7 +457,7 @@ def compute_requirement_template_table(
 
 def compute_source_template_table(
     cst_summaries: List[ComputeSourceTemplateSummary],
-) -> (List[str], List[List]):
+) -> Tuple[List[str], List[List]]:
     headers = [
         "#",
         "Name",
@@ -479,7 +493,7 @@ def compute_source_template_table(
 
 def keyring_table(
     keyring_summaries: List[KeyringSummary],
-) -> (List[str], List[List]):
+) -> Tuple[List[str], List[List]]:
     headers = [
         "#",
         "Name",
@@ -501,7 +515,7 @@ def keyring_table(
 
 def image_family_table(
     image_family_summaries: List[MachineImageFamilySummary],
-) -> (List[str], List[str]):
+) -> Tuple[List[str], List[str]]:
     headers = [
         "#",
         "Name",
@@ -527,7 +541,7 @@ def image_family_table(
 
 def object_path_table(
     object_paths: List[ObjectPath],
-) -> (List[str], List[str]):
+) -> Tuple[List[str], List[str]]:
     headers = ["#", "Name"]
     table = []
     for index, object_path in enumerate(object_paths):
@@ -537,7 +551,7 @@ def object_path_table(
 
 def instances_table(
     instances: List[Instance],
-) -> (List[str], List[str]):
+) -> Tuple[List[str], List[str]]:
     headers = [
         "#",
         "Provider",
@@ -565,7 +579,7 @@ def instances_table(
 
 def nodes_table(
     nodes: List[Node],
-) -> (List[str], List[str]):
+) -> Tuple[List[str], List[str]]:
     headers = [
         "#",
         "Worker Pool Name",
@@ -601,7 +615,7 @@ def nodes_table(
 
 def workers_table(
     workers: List[Worker],
-) -> (List[str], List[str]):
+) -> Tuple[List[str], List[str]]:
     headers = [
         "#",
         "Worker Pool Name",
@@ -631,7 +645,7 @@ def workers_table(
 
 def allowances_table(
     allowances: List[Allowance],
-) -> (List[str], List[str]):
+) -> Tuple[List[str], List[str]]:
     headers = [
         "#",
         "Type",
@@ -665,7 +679,7 @@ def allowances_table(
 
 def attribute_definitions_table(
     attribute_definitions: List[Dict],
-) -> (List[str], List[str]):
+) -> Tuple[List[str], List[str]]:
     headers = [
         "#",
         "Name",
@@ -689,7 +703,7 @@ def attribute_definitions_table(
 
 def aws_availability_zone_table(
     aws_azs: List[AWSAvailabilityZone],
-) -> (List[str], List[str]):
+) -> Tuple[List[str], List[str]]:
     headers = [
         "#",
         "Availability Zone",
@@ -709,9 +723,31 @@ def aws_availability_zone_table(
     return headers, table
 
 
+def namespaces_table(
+    ns_policies: List[Namespace],
+) -> Tuple[List[str], List[List]]:
+    headers = [
+        "#",
+        "Namespace Name",
+        "ID",
+        "Deletable",
+    ]
+    table = []
+    for index, namespace in enumerate(ns_policies):
+        table.append(
+            [
+                index + 1,
+                namespace.namespace,
+                namespace.id,
+                "Yes" if namespace.deletable else "No",
+            ]
+        )
+    return headers, table
+
+
 def namespace_policies_table(
     ns_policies: List[NamespacePolicy],
-) -> (List[str], List[List]):
+) -> Tuple[List[str], List[List]]:
     headers = [
         "#",
         "Namespace",
@@ -731,7 +767,7 @@ def namespace_policies_table(
 
 def users_table(
     users: List[User],
-) -> (List[str], List[List]):
+) -> Tuple[List[str], List[List]]:
     headers = [
         "#",
         "Name",
@@ -769,7 +805,7 @@ def users_table(
 
 def applications_table(
     applications: List[Application],
-) -> (List[str], List[List]):
+) -> Tuple[List[str], List[List]]:
     headers = [
         "#",
         "Name",
@@ -791,7 +827,7 @@ def applications_table(
 
 def groups_table(
     groups: List[Group],
-) -> (List[str], List[List]):
+) -> Tuple[List[str], List[List]]:
     headers = [
         "#",
         "Name",
@@ -817,7 +853,7 @@ def groups_table(
 
 def roles_table(
     roles: List[Role],
-) -> (List[str], List[List]):
+) -> Tuple[List[str], List[List]]:
     headers = [
         "#",
         "Name",
@@ -840,7 +876,7 @@ def roles_table(
 
 def permissions_table(
     permissions: List[PermissionDetail],
-) -> (List[str], List[List]):
+) -> Tuple[List[str], List[List]]:
     headers = [
         "#",
         "Name",
@@ -931,6 +967,8 @@ def print_numbered_object_list(
         headers, table = roles_table(objects)
     elif isinstance(objects[0], PermissionDetail):
         headers, table = permissions_table(objects)
+    elif isinstance(objects[0], Namespace):
+        headers, table = namespaces_table(objects)
     else:
         table = []
         for index, obj in enumerate(objects):
@@ -1048,7 +1086,7 @@ def print_json(
             CONSOLE_JSON.print(json_string, soft_wrap=True)
 
     if ARGS_PARSER.output_file is not None:  # Also output to a nominated file
-        _print_to_file(
+        print_to_file(
             json_string=json_string,
             output_file=ARGS_PARSER.output_file,
             with_final_comma=with_final_comma,
@@ -1081,6 +1119,9 @@ def print_yd_object(
                 if k
                 not in [
                     PROP_ID,
+                    PROP_ACCESS_DELEGATES,
+                    PROP_ADMIN_GROUP,
+                    PROP_CREATED_BY_USER_ID,
                     PROP_CREATED_TIME,
                     PROP_INSTANCE_PRICING,
                     PROP_SUPPORTING_RESOURCE_CREATED,
@@ -1111,7 +1152,7 @@ def print_yd_object(
 
 
 def print_yd_object_list(
-    objects: List[Tuple[Any, Optional[str]]],  # Tuples are (object, resource_type_name)
+    objects: List[Tuple[Any, Optional[Dict]]],
 ):
     """
     Print a JSON list of objects.
@@ -1123,24 +1164,20 @@ def print_yd_object_list(
     if len(objects) > 1:
         print("[")
         if ARGS_PARSER.output_file is not None:
-            _print_to_file("[", ARGS_PARSER.output_file)
+            print_to_file("[", ARGS_PARSER.output_file)
 
-    for index, (object_, resource_type_name) in enumerate(objects):
+    for index, (object_, add_fields) in enumerate(objects):
         print_yd_object(
             object_,
             initial_indent=2 if len(objects) > 1 else 0,
             with_final_comma=(True if index < len(objects) - 1 else False),
-            add_fields=(
-                {}
-                if resource_type_name is None
-                else {PROP_RESOURCE: resource_type_name}
-            ),
+            add_fields=add_fields,
         )
 
     if len(objects) > 1:
         print("]")
         if ARGS_PARSER.output_file is not None:
-            _print_to_file("]", ARGS_PARSER.output_file)
+            print_to_file("]", ARGS_PARSER.output_file)
 
 
 def print_worker_pool(
@@ -1501,7 +1538,7 @@ def print_event(event: str, id_type: YDIDType):
 FIRST_OUTPUT_TO_FILE = True  # Determine whether to 'write' or 'append'
 
 
-def _print_to_file(json_string: str, output_file: str, with_final_comma: bool = False):
+def print_to_file(json_string: str, output_file: str, with_final_comma: bool = False):
     """
     Dump details output to a file.
     """
